Package: matlab
Version: 1.0.4.1
Date: 2022-05-31
Title: 'MATLAB' Emulation Package
Author: P. Roebuck
Maintainer: P. Roebuck <proebuck1701@gmail.com>
Description: Emulate 'MATLAB' code using 'R'.
Depends: R (>= 2.15)
Imports: methods
URL: https://cran.r-project.org/package=matlab
License: Artistic-2.0
Copyright: file COPYRIGHTS
LazyLoad: true
NeedsCompilation: no
Repository: CRAN
Date/Publication: 2024-07-01 09:14:02 UTC
Repository/R-Forge/Project: estimate
Repository/R-Forge/Revision: 43
Repository/R-Forge/DateTimeStamp: 2022-05-31 23:32:38
Packaged: 2024-07-01 09:05:18 UTC; hornik
Built: R 4.6.0; ; 2026-04-25 15:57:43 UTC; unix
